@@ -13,23 +13,22 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 #include "config.h"
 
-#include <glib/gi18n.h>
-
 #include "seahorse-application.h"
-#include "seahorse-common.h"
 #include "seahorse-keyserver-control.h"
 #include "seahorse-prefs.h"
 #include "seahorse-servers.h"
 #include "seahorse-util.h"
 #include "seahorse-widget.h"
 
+#include "seahorse-common.h"
+
+#include <glib/gi18n.h>
+
 G_MODULE_EXPORT
 void           on_prefs_keyserver_add_clicked           (GtkButton *button,
                                                          gpointer user_data);
@@ -64,7 +63,7 @@ keyserver_cell_edited (GtkCellRendererText *cell, gchar *path, gchar *text,
 
     if (!seahorse_servers_is_valid_uri (text)) {
         seahorse_util_show_error (NULL, _("Not a valid Key Server address."), 
-                                  _("For help contact your system adminstrator or the administrator of the key server." ));
+                                  _("For help contact your system administrator or the administrator of the key server." ));
         return;
     }
 
