@@ -14,9 +14,8 @@
  * Lesser General Public License for more details.
  *  
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.  
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __SEAHORSE_KEY_MANAGER_H__
@@ -54,7 +53,7 @@ struct _SeahorseKeyManagerClass {
 
 GType            seahorse_key_manager_get_type     (void) G_GNUC_CONST;
 
-void             seahorse_key_manager_show         (void);
+SeahorseKeyManager * seahorse_key_manager_show     (guint32 timestamp);
 
 
 G_END_DECLS
